==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/analysis/api/renderer/declarations/KaRendererCodeStyle.kt <==
/*
 * Copyright 2010-2022 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.analysis.api.renderer.declarations

import ksp.org.jetbrains.kotlin.analysis.api.KaExperimentalApi
import ksp.org.jetbrains.kotlin.analysis.api.KaSession
import ksp.org.jetbrains.kotlin.analysis.api.annotations.KaAnnotated
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaDeclarationSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaEnumEntrySymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaTypeParameterSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaValueParameterSymbol
import ksp.org.jetbrains.kotlin.analysis.api.types.KaType

@KaExperimentalApi
public interface KaRendererCodeStyle {
    public fun getIndentSize(analysisSession: KaSession): Int

    public fun getSeparatorAfterContextReceivers(analysisSession: KaSession): String

    public fun getSeparatorBetweenAnnotationAndOwner(analysisSession: KaSession, symbol: KaAnnotated): String

    public fun getSeparatorBetweenAnnotations(analysisSession: KaSession, symbol: KaAnnotated): String

    public fun getSeparatorBetweenModifiers(analysisSession: KaSession): String

    public fun getSeparatorBetweenMembers(
        analysisSession: KaSession,
        first: KaDeclarationSymbol,
        second: KaDeclarationSymbol,
    ): String
}

@KaExperimentalApi
@Deprecated("Use 'KaRendererCodeStyle' instead", ReplaceWith("KaRendererCodeStyle"))
public typealias KtRendererCodeStyle = KaRendererCodeStyle

@KaExperimentalApi
public object KaRecommendedRendererCodeStyle : KaRendererCodeStyle {
    override fun getIndentSize(analysisSession: KaSession): Int = 4

    override fun getSeparatorAfterContextReceivers(analysisSession: KaSession): String = "\n"

    override fun getSeparatorBetweenAnnotationAndOwner(analysisSession: KaSession, symbol: KaAnnotated): String {
        return when (symbol) {
            is KaType -> " "
            is KaTypeParameterSymbol -> " "
            is KaValueParameterSymbol -> " "
            else -> "\n"
        }
    }

    override fun getSeparatorBetweenAnnotations(analysisSession: KaSession, symbol: KaAnnotated): String {
        return when (symbol) {
            is KaType -> " "
            is KaTypeParameterSymbol -> " "
            is KaValueParameterSymbol -> " "
            else -> "\n"
        }
    }

    override fun getSeparatorBetweenModifiers(analysisSession: KaSession): String = " "

    override fun getSeparatorBetweenMembers(analysisSession: KaSession, first: KaDeclarationSymbol, second: KaDeclarationSymbol): String {
        return when {
            first is KaEnumEntrySymbol && second is KaEnumEntrySymbol -> ",\n"
            first is KaEnumEntrySymbol && second !is KaEnumEntrySymbol -> ";\n\n"
            else -> "\n\n"
        }
    }
}

@KaExperimentalApi
@Deprecated("Use 'KaRecommendedRendererCodeStyle' instead", ReplaceWith("KaRecommendedRendererCodeStyle"))
public typealias KtRecommendedRendererCodeStyle = KaRecommendedRendererCodeStyle

==> symbol-processing-aa-embeddable-2.3.3-sources.jar: org/jetbrains/kotlin/analysis/api/renderer/declarations/KaRendererCodeStyle.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.analysis.api.renderer.declarations

import ksp.org.jetbrains.kotlin.analysis.api.KaExperimentalApi
import ksp.org.jetbrains.kotlin.analysis.api.KaSession
import ksp.org.jetbrains.kotlin.analysis.api.annotations.KaAnnotated
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaDeclarationSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaEnumEntrySymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaParameterSymbol
import ksp.org.jetbrains.kotlin.analysis.api.symbols.KaTypeParameterSymbol
import ksp.org.jetbrains.kotlin.analysis.api.types.KaType

@KaExperimentalApi
public interface KaRendererCodeStyle {
    public fun getIndentSize(analysisSession: KaSession): Int

    public fun getSeparatorAfterContextReceivers(analysisSession: KaSession): String

    public fun getSeparatorBetweenAnnotationAndOwner(analysisSession: KaSession, symbol: KaAnnotated): String

    public fun getSeparatorBetweenAnnotations(analysisSession: KaSession, symbol: KaAnnotated): String

    public fun getSeparatorBetweenModifiers(analysisSession: KaSession): String

    public fun getSeparatorBetweenMembers(
        analysisSession: KaSession,
        first: KaDeclarationSymbol,
        second: KaDeclarationSymbol,
    ): String
}

@KaExperimentalApi
public object KaRecommendedRendererCodeStyle : KaRendererCodeStyle {
    override fun getIndentSize(analysisSession: KaSession): Int = 4

    override fun getSeparatorAfterContextReceivers(analysisSession: KaSession): String = "\n"

    override fun getSeparatorBetweenAnnotationAndOwner(analysisSession: KaSession, symbol: KaAnnotated): String = when (symbol) {
        is KaType -> " "
        is KaTypeParameterSymbol -> " "
        is KaParameterSymbol -> " "
        else -> "\n"
    }

    override fun getSeparatorBetweenAnnotations(analysisSession: KaSession, symbol: KaAnnotated): String = when (symbol) {
        is KaType -> " "
        is KaTypeParameterSymbol -> " "
        is KaParameterSymbol -> " "
        else -> "\n"
    }

    override fun getSeparatorBetweenModifiers(analysisSession: KaSession): String = " "

    override fun getSeparatorBetweenMembers(analysisSession: KaSession, first: KaDeclarationSymbol, second: KaDeclarationSymbol): String {
        return when {
            first is KaEnumEntrySymbol && second is KaEnumEntrySymbol -> ",\n"
            first is KaEnumEntrySymbol && second !is KaEnumEntrySymbol -> ";\n\n"
            else -> "\n\n"
        }
    }
}
